#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent-postgresql
version:              2.13.0.2
visibility:           public
id:                   persistent-postgresql-2.13.0.2-HC0k9xn6PEL8xYKn21hAzN
key:                  persistent-postgresql-2.13.0.2-HC0k9xn6PEL8xYKn21hAzN
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Felipe Lessa, Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Backend for the persistent library using postgresql.
description:          Based on the postgresql-simple package
category:             Database, Yesod
abi:                  3ea59cbcf5ed48b90300192ae974b968
exposed:              True
exposed-modules:
    Database.Persist.Postgresql Database.Persist.Postgresql.JSON

import-dirs:
    /usr/lib/ghc-8.10.5/site-local/persistent-postgresql-2.13.0.2

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/persistent-postgresql-2.13.0.2

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/persistent-postgresql-2.13.0.2

hs-libraries:         HSpersistent-postgresql-2.13.0.2-HC0k9xn6PEL8xYKn21hAzN
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE containers-0.6.4.1
    monad-logger-0.3.36-1GrKwR43Dhh83kQQb62BZS mtl-2.2.2
    persistent-2.13.0.2-La3E9BZccdVB7xnmOANUxr
    postgresql-libpq-0.9.4.3-GURAPDQPILI44u2l0Z99kj
    postgresql-simple-0.6.4-KqiM5CvOYBOCeQAsSa8zUc
    resource-pool-0.2.3.2-HuMDXx2LvNiFKUxNwBNmWZ
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe
    string-conversions-0.4.0.1-2hCpm9KzYph7xvod4dEvyg text-1.2.4.1
    time-1.9.3 transformers-0.5.6.2
    unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp

haddock-interfaces:
    /usr/share/doc/haskell-persistent-postgresql/html/persistent-postgresql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-postgresql/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

